==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXGpu.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXGpu::getGpuIndex{package NXGpu;no warnings;(my $gpuIndex=(""));if ((
$GLOBAL::GPULoadBalancingAlgorithm eq "\x6e\x6f\x6e\x65")){if ((
$GLOBAL::GPUDedicatedDevice ne (""))){($gpuIndex=__getGpuIndexByUUID (
$GLOBAL::GPUDedicatedDevice));}else{return ((""));}}elsif ((
$GLOBAL::GPULoadBalancingAlgorithm eq 
"\x72\x6f\x75\x6e\x64\x2d\x72\x6f\x62\x69\x6e")){($gpuIndex=
__getGpuIndexByRoundRobinAlgo ());}elsif (($GLOBAL::GPULoadBalancingAlgorithm eq
 "\x6c\x6f\x61\x64\x2d\x62\x61\x73\x65\x64")){($gpuIndex=__getGpuIndexByLoad ())
;}else{Logger::warning (((
"\x4e\x58\x47\x70\x75\x3a\x20\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x47\x50\x55\x20\x64\x65\x76\x69\x63\x65\x20\x73\x65\x6c\x65\x63\x74\x69\x6f\x6e\x20\x61\x6c\x67\x6f\x72\x69\x74\x68\x6d\x20\x27"
.$GLOBAL::GPULoadBalancingAlgorithm)."\x27\x2e"));}if (($gpuIndex ne (""))){
Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x53\x65\x6c\x65\x63\x74\x65\x64\x20\x67\x70\x75\x20\x77\x69\x74\x68\x20\x69\x6e\x64\x65\x78\x20\x27"
.$gpuIndex)."\x27\x2e"));}else{Logger::warning (
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x6c\x65\x63\x74\x20\x67\x70\x75\x20\x69\x6e\x64\x65\x78\x2e"
);}return ($gpuIndex);}sub NXGpu::__getGpuIndexByUUID{package NXGpu;no warnings;
(my $uuid=shift (@_));Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x53\x65\x6c\x65\x63\x74\x69\x6e\x67\x20\x67\x70\x75\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x55\x55\x49\x44\x20\x27"
.$uuid)."\x27\x2e"));if ((not (__initNvml ()))){return ((""));}Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x49\x6e\x64\x65\x78\x42\x79\x55\x75\x69\x64\x28"
.$uuid)."\x29\x20\x73\x74\x61\x72\x74\x2e"));(my $gpuIndex=
libnxhs::NXGetGpuIndexByUuid ($uuid));Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x49\x6e\x64\x65\x78\x42\x79\x55\x75\x69\x64\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$gpuIndex)."\x27\x2e"));if (($gpuIndex==(-(0x0395+ 8787-0x25e7)))){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning (((
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x47\x50\x55\x20\x69\x6e\x64\x65\x78\x20\x62\x79\x20\x55\x55\x49\x44\x20\x27"
.$uuid).
"\x27\x20\x66\x72\x6f\x6d\x20\x4e\x76\x69\x64\x69\x61\x20\x6d\x61\x6e\x61\x67\x65\x6d\x65\x6e\x74\x20\x6c\x69\x62\x72\x61\x72\x79\x2e"
));Logger::warning (((((
"\x4e\x58\x47\x70\x75\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".
$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e"));return ((""));}
__closeNvml ();return ($gpuIndex);}sub NXGpu::__getGpuIndexByRoundRobinAlgo{
package NXGpu;no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x53\x65\x6c\x65\x63\x74\x69\x6e\x67\x20\x67\x70\x75\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x72\x6f\x75\x6e\x64\x2d\x72\x6f\x62\x69\x6e\x20\x61\x6c\x67\x6f\x72\x69\x74\x68\x6d\x2e"
);if ((not (__initNvml ()))){return ((""));}(my $gpuCount=__getDeviceCount ());
if (($gpuCount eq (""))){return ((""));}(my $gpuIndex=__takeRoundRobinGpuIndex (
$gpuCount));Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x50\x63\x69\x42\x75\x73\x49\x44\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $busID=libnxhs::NXGetGpuPciBusID ($gpuIndex));Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x50\x63\x69\x42\x75\x73\x49\x44\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$busID)."\x27\x2e"));__closeNvml ();return ($busID);}sub 
NXGpu::__getGpuIndexByLoad{package NXGpu;no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x53\x65\x6c\x65\x63\x74\x69\x6e\x67\x20\x67\x70\x75\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x6c\x6f\x61\x64\x2e"
);if ((not (__initNvml ()))){return ((""));}Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x4e\x65\x78\x74\x47\x70\x75\x42\x79\x45\x6e\x63\x55\x74\x69\x6c\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $gpuIndex=libnxhs::NXGetNextGpuByEncUtil ());Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x4e\x65\x78\x74\x47\x70\x75\x42\x79\x45\x6e\x63\x55\x74\x69\x6c\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$gpuIndex)."\x27\x2e"));__closeNvml ();return ($gpuIndex);}sub 
NXGpu::__getDeviceCount{package NXGpu;no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x43\x6f\x75\x6e\x74\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $gpuCount=libnxhs::NXGetGpuCount ());Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x43\x6f\x75\x6e\x74\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$gpuCount)."\x27\x2e"));if (($gpuCount==(-(0x0f81+ 741-0x1265)))){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning (
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x47\x50\x55\x20\x63\x6f\x75\x6e\x74\x20\x66\x72\x6f\x6d\x20\x4e\x76\x69\x64\x69\x61\x20\x6d\x61\x6e\x61\x67\x65\x6d\x65\x6e\x74\x20\x6c\x69\x62\x72\x61\x72\x79\x2e"
);Logger::warning (((((
"\x4e\x58\x47\x70\x75\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".
$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e"));return (
(0x1ada+ 916-0x1e6e));}return ($gpuCount);}sub NXGpu::__initNvml{package NXGpu;
no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x49\x6e\x69\x74\x4e\x76\x6d\x6c\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $return=libnxhs::NXInitNvml ());Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x49\x6e\x69\x74\x4e\x76\x6d\x6c\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$return)."\x27\x2e"));if (($return==(-(0x080f+ 1097-0x0c57)))){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning (
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x20\x4e\x76\x69\x64\x69\x61\x20\x6d\x61\x6e\x61\x67\x65\x6d\x65\x6e\x74\x20\x6c\x69\x62\x72\x61\x72\x79\x2e"
);Logger::warning (((((
"\x4e\x58\x47\x70\x75\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".
$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e"));return (
(0x1fc7+ 743-0x22ae));}return ((0x0835+ 4307-0x1907));}sub NXGpu::__closeNvml{
package NXGpu;no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x43\x6c\x6f\x73\x65\x4e\x76\x6d\x6c\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $return=libnxhs::NXCloseNvml ());Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x43\x6c\x6f\x73\x65\x4e\x76\x6d\x6c\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$return)."\x27\x2e"));if (($return==(-(0x0a08+ 5426-0x1f39)))){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning (
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x6c\x6f\x73\x65\x20\x4e\x76\x69\x64\x69\x61\x20\x6d\x61\x6e\x61\x67\x65\x6d\x65\x6e\x74\x20\x6c\x69\x62\x72\x61\x72\x79\x2e"
);Logger::warning (((((
"\x4e\x58\x47\x70\x75\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".
$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e"));}}sub 
NXGpu::__takeRoundRobinGpuIndex{package NXGpu;no warnings;(my $gpuCount=shift (
@_));NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x72\x6f\x75\x6e\x64\x72\x6f\x62\x69\x6e\x67\x70\x75\x2c\x66\x69\x65\x6c\x64\x3d\x69\x6e\x64\x65\x78\x0a"
);(my $index=NXRedis::get ());if (($index ne (""))){($index=
__getNextRoundRobinGpuIndex ($index,$gpuCount));}else{($index=
(0x042b+ 2178-0x0cad));}NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x72\x6f\x75\x6e\x64\x72\x6f\x62\x69\x6e\x67\x70\x75\x2c\x66\x69\x65\x6c\x64\x3d\x69\x6e\x64\x65\x78\x2c\x76\x61\x6c\x75\x65\x3d"
.$index)."\x0a"));return ($index);}sub NXGpu::__getNextRoundRobinGpuIndex{
package NXGpu;no warnings;(my $index=shift (@_));(my $gpuCount=shift (@_));if ((
($index>=(0x0101+ 6136-0x18f9))and ($index<($gpuCount-(0x20b0+ 157-0x214c))))){(
++$index);}else{($index=(0x0493+ 7828-0x2327));}return ($index);}package NXGpu;
no warnings;return ((0x0b8b+ 4362-0x1c94));

==> nomachine-8.16.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXGpu.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2025 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXGpu::getGpuIndex{package NXGpu;no warnings;(my $gpuIndex=(""));if ((
$GLOBAL::GPULoadBalancingAlgorithm eq "\x6e\x6f\x6e\x65")){if ((
$GLOBAL::GPUDedicatedDevice ne (""))){($gpuIndex=__getGpuIndexByUUID (
$GLOBAL::GPUDedicatedDevice));}else{return ((""));}}elsif ((
$GLOBAL::GPULoadBalancingAlgorithm eq 
"\x72\x6f\x75\x6e\x64\x2d\x72\x6f\x62\x69\x6e")){($gpuIndex=
__getGpuIndexByRoundRobinAlgo ());}elsif (($GLOBAL::GPULoadBalancingAlgorithm eq
 "\x6c\x6f\x61\x64\x2d\x62\x61\x73\x65\x64")){($gpuIndex=__getGpuIndexByLoad ())
;}else{Logger::warning (((
"\x4e\x58\x47\x70\x75\x3a\x20\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x47\x50\x55\x20\x64\x65\x76\x69\x63\x65\x20\x73\x65\x6c\x65\x63\x74\x69\x6f\x6e\x20\x61\x6c\x67\x6f\x72\x69\x74\x68\x6d\x20\x27"
.$GLOBAL::GPULoadBalancingAlgorithm)."\x27\x2e"));}if (($gpuIndex ne (""))){
Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x53\x65\x6c\x65\x63\x74\x65\x64\x20\x67\x70\x75\x20\x77\x69\x74\x68\x20\x69\x6e\x64\x65\x78\x20\x27"
.$gpuIndex)."\x27\x2e"));}else{Logger::warning (
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x6c\x65\x63\x74\x20\x67\x70\x75\x20\x69\x6e\x64\x65\x78\x2e"
);}return ($gpuIndex);}sub NXGpu::__getGpuIndexByUUID{package NXGpu;no warnings;
(my $uuid=shift (@_));Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x53\x65\x6c\x65\x63\x74\x69\x6e\x67\x20\x67\x70\x75\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x55\x55\x49\x44\x20\x27"
.$uuid)."\x27\x2e"));if ((not (__initNvml ()))){return ((""));}Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x49\x6e\x64\x65\x78\x42\x79\x55\x75\x69\x64\x28"
.$uuid)."\x29\x20\x73\x74\x61\x72\x74\x2e"));(my $gpuIndex=
libnxhs::NXGetGpuIndexByUuid ($uuid));Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x49\x6e\x64\x65\x78\x42\x79\x55\x75\x69\x64\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$gpuIndex)."\x27\x2e"));if (($gpuIndex==(-(0x1246+ 1727-0x1904)))){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning (((
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x47\x50\x55\x20\x69\x6e\x64\x65\x78\x20\x62\x79\x20\x55\x55\x49\x44\x20\x27"
.$uuid).
"\x27\x20\x66\x72\x6f\x6d\x20\x4e\x76\x69\x64\x69\x61\x20\x6d\x61\x6e\x61\x67\x65\x6d\x65\x6e\x74\x20\x6c\x69\x62\x72\x61\x72\x79\x2e"
));Logger::warning (((((
"\x4e\x58\x47\x70\x75\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".
$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e"));return ((""));}
__closeNvml ();return ($gpuIndex);}sub NXGpu::__getGpuIndexByRoundRobinAlgo{
package NXGpu;no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x53\x65\x6c\x65\x63\x74\x69\x6e\x67\x20\x67\x70\x75\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x72\x6f\x75\x6e\x64\x2d\x72\x6f\x62\x69\x6e\x20\x61\x6c\x67\x6f\x72\x69\x74\x68\x6d\x2e"
);if ((not (__initNvml ()))){return ((""));}(my $gpuCount=__getDeviceCount ());
if (($gpuCount eq (""))){return ((""));}(my $gpuIndex=__takeRoundRobinGpuIndex (
$gpuCount));Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x50\x63\x69\x42\x75\x73\x49\x44\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $busID=libnxhs::NXGetGpuPciBusID ($gpuIndex));Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x50\x63\x69\x42\x75\x73\x49\x44\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$busID)."\x27\x2e"));__closeNvml ();return ($busID);}sub 
NXGpu::__getGpuIndexByLoad{package NXGpu;no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x53\x65\x6c\x65\x63\x74\x69\x6e\x67\x20\x67\x70\x75\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x6c\x6f\x61\x64\x2e"
);if ((not (__initNvml ()))){return ((""));}Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x4e\x65\x78\x74\x47\x70\x75\x42\x79\x45\x6e\x63\x55\x74\x69\x6c\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $gpuIndex=libnxhs::NXGetNextGpuByEncUtil ());Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x4e\x65\x78\x74\x47\x70\x75\x42\x79\x45\x6e\x63\x55\x74\x69\x6c\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$gpuIndex)."\x27\x2e"));__closeNvml ();return ($gpuIndex);}sub 
NXGpu::__getDeviceCount{package NXGpu;no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x43\x6f\x75\x6e\x74\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $gpuCount=libnxhs::NXGetGpuCount ());Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x47\x65\x74\x47\x70\x75\x43\x6f\x75\x6e\x74\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$gpuCount)."\x27\x2e"));if (($gpuCount==(-(0x0887+ 2864-0x13b6)))){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning (
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x47\x50\x55\x20\x63\x6f\x75\x6e\x74\x20\x66\x72\x6f\x6d\x20\x4e\x76\x69\x64\x69\x61\x20\x6d\x61\x6e\x61\x67\x65\x6d\x65\x6e\x74\x20\x6c\x69\x62\x72\x61\x72\x79\x2e"
);Logger::warning (((((
"\x4e\x58\x47\x70\x75\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".
$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e"));return (
(0x0608+ 1845-0x0d3d));}return ($gpuCount);}sub NXGpu::__initNvml{package NXGpu;
no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x49\x6e\x69\x74\x4e\x76\x6d\x6c\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $return=libnxhs::NXInitNvml ());Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x49\x6e\x69\x74\x4e\x76\x6d\x6c\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$return)."\x27\x2e"));if (($return==(-(0x0641+ 4244-0x16d4)))){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning (
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x20\x4e\x76\x69\x64\x69\x61\x20\x6d\x61\x6e\x61\x67\x65\x6d\x65\x6e\x74\x20\x6c\x69\x62\x72\x61\x72\x79\x2e"
);Logger::warning (((((
"\x4e\x58\x47\x70\x75\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".
$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e"));return (
(0x0636+ 2538-0x1020));}return ((0x0e64+ 5719-0x24ba));}sub NXGpu::__closeNvml{
package NXGpu;no warnings;Logger::debug (
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x43\x6c\x6f\x73\x65\x4e\x76\x6d\x6c\x28\x29\x20\x73\x74\x61\x72\x74\x2e"
);(my $return=libnxhs::NXCloseNvml ());Logger::debug (((
"\x4e\x58\x47\x70\x75\x3a\x20\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x43\x6c\x6f\x73\x65\x4e\x76\x6d\x6c\x28\x29\x20\x65\x6e\x64\x20\x77\x69\x74\x68\x20\x72\x65\x73\x75\x6c\x74\x20\x27"
.$return)."\x27\x2e"));if (($return==(-(0x033f+ 7739-0x2179)))){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning (
"\x4e\x58\x47\x70\x75\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x6c\x6f\x73\x65\x20\x4e\x76\x69\x64\x69\x61\x20\x6d\x61\x6e\x61\x67\x65\x6d\x65\x6e\x74\x20\x6c\x69\x62\x72\x61\x72\x79\x2e"
);Logger::warning (((((
"\x4e\x58\x47\x70\x75\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".
$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e"));}}sub 
NXGpu::__takeRoundRobinGpuIndex{package NXGpu;no warnings;(my $gpuCount=shift (
@_));NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x72\x6f\x75\x6e\x64\x72\x6f\x62\x69\x6e\x67\x70\x75\x2c\x66\x69\x65\x6c\x64\x3d\x69\x6e\x64\x65\x78\x0a"
);(my $index=NXRedis::get ());if (($index ne (""))){($index=
__getNextRoundRobinGpuIndex ($index,$gpuCount));}else{($index=
(0x003f+  72-0x0087));}NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x72\x6f\x75\x6e\x64\x72\x6f\x62\x69\x6e\x67\x70\x75\x2c\x66\x69\x65\x6c\x64\x3d\x69\x6e\x64\x65\x78\x2c\x76\x61\x6c\x75\x65\x3d"
.$index)."\x0a"));return ($index);}sub NXGpu::__getNextRoundRobinGpuIndex{
package NXGpu;no warnings;(my $index=shift (@_));(my $gpuCount=shift (@_));if ((
($index>=(0x002f+ 9165-0x23fc))and ($index<($gpuCount-(0x1279+ 1435-0x1813))))){
(++$index);}else{($index=(0x1735+ 1327-0x1c64));}return ($index);}package NXGpu;
no warnings;return ((0x012d+ 7272-0x1d94));
